'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.__RewireAPI__ = exports.__ResetDependency__ = exports.__set__ = exports.__Rewire__ = exports.__GetDependency__ = exports.__get__ = exports.fieldClasses = undefined;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.FieldRenderer = FieldRenderer;
exports.CustomFieldRenderer = CustomFieldRenderer;
exports.LabelledField = LabelledField;
exports.CustomField = CustomField;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reduxForm = require('redux-form');

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var fieldClasses = exports.fieldClasses = function fieldClasses(className, errorClass, meta) {
    return _get__('classNames')(className, _defineProperty({}, errorClass, meta.touched && meta.error));
};
var createInlineError = function createInlineError(name, inlineErrorClass, meta) {
    if (meta.touched && meta.error) {
        return _get__('React').createElement(
            'div',
            { id: 'error-' + name, role: 'alert', 'aria-live': 'assertive', className: inlineErrorClass },
            meta.error
        );
    }
    return null;
};

function FieldRenderer(_ref) {
    var input = _ref.input,
        meta = _ref.meta,
        type = _ref.type,
        label = _ref.label,
        className = _ref.className,
        inputClass = _ref.inputClass,
        labelClass = _ref.labelClass,
        errorClass = _ref.errorClass,
        inlineErrorClass = _ref.inlineErrorClass,
        props = _objectWithoutProperties(_ref, ['input', 'meta', 'type', 'label', 'className', 'inputClass', 'labelClass', 'errorClass', 'inlineErrorClass']);

    var name = input.name;

    var inlineError = _get__('createInlineError')(name, inlineErrorClass, meta);
    var ekstraProps = _extends({
        'aria-invalid': meta.touched && !!meta.error,
        'aria-describedby': meta.touched && meta.error ? 'error-' + name : '',
        id: name
    }, props);

    return _get__('React').createElement(
        'div',
        { className: _get__('fieldClasses')(className, errorClass, meta) },
        _get__('React').createElement(
            'label',
            { className: labelClass, htmlFor: name },
            label
        ),
        _get__('React').createElement('input', _extends({ className: inputClass, type: type }, input, ekstraProps)),
        inlineError
    );
}

function CustomFieldRenderer(_ref2) {
    var input = _ref2.input,
        meta = _ref2.meta,
        customComponent = _ref2.customComponent,
        className = _ref2.className,
        errorClass = _ref2.errorClass,
        inlineErrorClass = _ref2.inlineErrorClass,
        props = _objectWithoutProperties(_ref2, ['input', 'meta', 'customComponent', 'className', 'errorClass', 'inlineErrorClass']);

    var name = input.name;
    var inlineError = _get__('createInlineError')(name, inlineErrorClass, meta);
    var ekstraProps = _extends({
        'aria-invalid': meta.touched && !!meta.error,
        'aria-describedby': meta.touched && meta.error ? 'error-' + name : '',
        id: name
    }, props);

    var augmentedComponent = _get__('cloneElement')(customComponent, _extends({}, ekstraProps, { input: input, meta: meta }));

    return _get__('React').createElement(
        'div',
        { className: _get__('fieldClasses')(className, errorClass, meta) },
        augmentedComponent,
        inlineError
    );
}

_get__('FieldRenderer').propTypes = {
    input: _get__('PT').object.isRequired, // eslint-disable-line react/forbid-prop-types
    meta: _get__('PT').object.isRequired, // eslint-disable-line react/forbid-prop-types
    type: _get__('PT').string.isRequired,
    label: _get__('PT').node.isRequired,
    className: _get__('PT').string,
    inputClass: _get__('PT').string,
    labelClass: _get__('PT').string,
    errorClass: _get__('PT').string,
    inlineErrorClass: _get__('PT').string
};

_get__('CustomFieldRenderer').propTypes = {
    input: _get__('PT').object.isRequired, // eslint-disable-line react/forbid-prop-types
    meta: _get__('PT').object.isRequired, // eslint-disable-line react/forbid-prop-types
    customComponent: _get__('PT').node.isRequired,
    className: _get__('PT').string,
    errorClass: _get__('PT').string,
    inlineErrorClass: _get__('PT').string
};

_get__('FieldRenderer').defaultProps = {
    errorClass: 'has-errors',
    inlineErrorClass: 'inline-error-message'
};

_get__('CustomFieldRenderer').defaultProps = {
    errorClass: 'has-errors',
    inlineErrorClass: 'inline-error-message'
};

function LabelledField(_ref3) {
    var children = _ref3.children,
        props = _objectWithoutProperties(_ref3, ['children']);

    return _get__('React').createElement(_get__('Field'), _extends({}, props, { component: _get__('FieldRenderer'), label: children }));
}

function CustomField(_ref4) {
    var props = _objectWithoutProperties(_ref4, []);

    return _get__('React').createElement(_get__('Field'), _extends({}, props, { component: _get__('CustomFieldRenderer') }));
}

_get__('LabelledField').propTypes = {
    children: _get__('PT').node.isRequired
};

_get__('CustomField').propTypes = {};

var _RewiredData__ = Object.create(null);

var INTENTIONAL_UNDEFINED = '__INTENTIONAL_UNDEFINED__';
var _RewireAPI__ = {};

(function () {
    function addPropertyToAPIObject(name, value) {
        Object.defineProperty(_RewireAPI__, name, {
            value: value,
            enumerable: false,
            configurable: true
        });
    }

    addPropertyToAPIObject('__get__', _get__);
    addPropertyToAPIObject('__GetDependency__', _get__);
    addPropertyToAPIObject('__Rewire__', _set__);
    addPropertyToAPIObject('__set__', _set__);
    addPropertyToAPIObject('__reset__', _reset__);
    addPropertyToAPIObject('__ResetDependency__', _reset__);
    addPropertyToAPIObject('__with__', _with__);
})();

function _get__(variableName) {
    if (_RewiredData__ === undefined || _RewiredData__[variableName] === undefined) {
        return _get_original__(variableName);
    } else {
        var value = _RewiredData__[variableName];

        if (value === INTENTIONAL_UNDEFINED) {
            return undefined;
        } else {
            return value;
        }
    }
}

function _get_original__(variableName) {
    switch (variableName) {
        case 'classNames':
            return _classnames2.default;

        case 'createInlineError':
            return createInlineError;

        case 'fieldClasses':
            return fieldClasses;

        case 'cloneElement':
            return _react.cloneElement;

        case 'FieldRenderer':
            return FieldRenderer;

        case 'PT':
            return _react.PropTypes;

        case 'CustomFieldRenderer':
            return CustomFieldRenderer;

        case 'LabelledField':
            return LabelledField;

        case 'CustomField':
            return CustomField;

        case 'React':
            return _react2.default;

        case 'Field':
            return _reduxForm.Field;
    }

    return undefined;
}

function _assign__(variableName, value) {
    if (_RewiredData__ === undefined || _RewiredData__[variableName] === undefined) {
        return _set_original__(variableName, value);
    } else {
        return _RewiredData__[variableName] = value;
    }
}

function _set_original__(variableName, _value) {
    switch (variableName) {}

    return undefined;
}

function _update_operation__(operation, variableName, prefix) {
    var oldValue = _get__(variableName);

    var newValue = operation === '++' ? oldValue + 1 : oldValue - 1;

    _assign__(variableName, newValue);

    return prefix ? newValue : oldValue;
}

function _set__(variableName, value) {
    if ((typeof variableName === 'undefined' ? 'undefined' : _typeof(variableName)) === 'object') {
        Object.keys(variableName).forEach(function (name) {
            _RewiredData__[name] = variableName[name];
        });
    } else {
        if (value === undefined) {
            _RewiredData__[variableName] = INTENTIONAL_UNDEFINED;
        } else {
            _RewiredData__[variableName] = value;
        }

        return function () {
            _reset__(variableName);
        };
    }
}

function _reset__(variableName) {
    delete _RewiredData__[variableName];
}

function _with__(object) {
    var rewiredVariableNames = Object.keys(object);
    var previousValues = {};

    function reset() {
        rewiredVariableNames.forEach(function (variableName) {
            _RewiredData__[variableName] = previousValues[variableName];
        });
    }

    return function (callback) {
        rewiredVariableNames.forEach(function (variableName) {
            previousValues[variableName] = _RewiredData__[variableName];
            _RewiredData__[variableName] = object[variableName];
        });
        var result = callback();

        if (!!result && typeof result.then == 'function') {
            result.then(reset).catch(reset);
        } else {
            reset();
        }

        return result;
    };
}

exports.__get__ = _get__;
exports.__GetDependency__ = _get__;
exports.__Rewire__ = _set__;
exports.__set__ = _set__;
exports.__ResetDependency__ = _reset__;
exports.__RewireAPI__ = _RewireAPI__;
exports.default = _RewireAPI__;